<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>Neplatný priečinok</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvoriť priečinok</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemáte povolenie na používanie tohto priečinka</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>Automatické pridanie podobných súborov na prehrávanie</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>Vymazanie zoznamu skladieb pri ukončení</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>Zobraziť náhľad videa po prechode myšou</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>Otvoriť nový prehrávač pre každý prehrávaný súbor</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>Pozastaviť pri minimalizácii</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>Zapamätať pozíciu prehrávania</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základné</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Snímok obrazovky</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Odkazy</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>Rámec/Zvuk</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>Prehrávanie</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Titulky</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>Štýl písma</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Obnoviť predvolené nastavenia</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>Otvoriť ďalšie</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>Otvoriť predošlé</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>Mini režim</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Ďalší snímok</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Predchádzajúci snímok</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Tichšie</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Hlasnejšie</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>Zvýšiť rýchlosť</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>Znížiť rýchlosť</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pozastaviť/Spustiť</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Zoznam skladieb</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>Resetovať rýchlosť</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Dozadu</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Dopredu</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Snímka filmu</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0,5 s dozadu</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0,5 s dopredu</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápoveda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobraziť skratky</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Informácie o filme</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>Prosím zadajte URL adresu:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>Vždy navrchu</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Informácie o filme</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvoriť priečinok</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Otvoriť URL</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>Otvoriť CD/DVD</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>Malý režim</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>Režim prehrávania</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>Prehrávanie podľa poradia</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>Shuffle prehrávanie</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>Jednoduché prehrávanie</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>Jedna slučka</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>Zoznam slučiek</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>Rámec</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>V smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>Proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Ľavý kanál</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Pravý kanál</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Titulky</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Nahrať</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>Online vyhľadávanie</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrať</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Skryť</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>Kódovanie</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Snímok obrazovky</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>Snímka filmu</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>Sekvenčné snímanie</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Zoznam skladieb</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>Informácie o filme</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobraziť v správcovi súborov</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>Doba trvania: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>Rozlíšenie: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>Veľkosť: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>Nahrávanie úspešné</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>Nahrávanie zlyhalo</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation>Ukladá sa do vyrovnávacej pamäte...</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvoriť priečinok</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Ľavý kanál</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Pravý kanál</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>Hlasitosť: %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>Titulky %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>oneskorené</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>pokročilé</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>Rýchlosť: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Uložené na</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>Snímok obrazovky sa uložil</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>Nepodarilo sa uložiť snímku obrazovky</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>Neplatný súbor: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Neplatný súbor</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Snímka filmu</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Titulky (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušiť</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>Informácie o filme</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlíšenie</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Doba trvania</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">Nahrávanie úspešné</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">Nahrávanie zlyhalo</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">Otvoriť priečinok</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">Rýchlosť: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">Ľavý kanál</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">Pravý kanál</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Titulky %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">oneskorené</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">pokročilé</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Titulky (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Náhľad</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">Snímka filmu</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Uložené na</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Snímok obrazovky sa uložil</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Nepodarilo sa uložiť snímku obrazovky</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished">Ukladá sa do vyrovnávacej pamäte...</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">Stlmiť</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">Hlasitosť: %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Neplatný súbor</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Neplatný súbor: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušiť</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Zoznam skladieb</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">Vysypať</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">Prehrať/pozastaviť</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Predchádzajúce</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Ďalšie</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Celá obrazovka</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Zoznam skladieb</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Zrušiť celú obrazovku</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">Pozastaviť</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Spustiť</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>Zoznam skladieb</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vysypať</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Predchádzajúce</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Ďalšie</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Zoznam skladieb</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Prehrať/pozastaviť</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Zrušiť celú obrazovku</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
